Sys.info()

require("syskern")

is.S()

dateParsed()
